@@ -10,9 +10,9 @@ class SGraph:
         self.pi = None
 
     def clean_copy(self):
-        G = self.gr.__class__()
-        G.add_edges_from(self.gr.edges())
-        return SGraph(G)
+        g = self.gr.__class__()
+        g.add_edges_from(self.gr.edges())
+        return SGraph(g)
 
     def directed(self):
         return nx.is_directed(self.get_nx_graph())
@@ -111,8 +111,11 @@ class SGraph:
                 res.append(noneval)
         return np.array(res)
 
-    def get_attrs_dict(self, attr):
-        return nx.get_node_attributes(self.gr, attr)
+    def get_attrs_dict(self, attr, nodes=None):
+        res = nx.get_node_attributes(self.gr, attr)
+        if nodes is None:
+            return res
+        return {k: res[k] for k in res.keys() if k in nodes}
 
     def get_nx_graph(self):
         return self.gr
@@ -139,8 +142,11 @@ class SGraph:
                 self.pi = np.ones(self.size())
         return self.pi
 
-    def add_edge(self, u, v):
-        self.gr.add_edge(u, v)
+    def add_edge(self, u, v, key=None, prms=None):
+        if prms is None:
+            self.gr.add_edge(u, v, key=key)
+        else:
+            self.gr.add_edge(u, v, key=key, **prms)
 
     def add_edges(self, edges):
         self.gr.add_edges_from(edges)
@@ -175,7 +181,7 @@ class SGraph:
         res = self.get_in_degrees(ind, w=w, bsc=1)
         return np.sum(res)
 
-    def count_out_degree(self, out, w=None,):
+    def count_out_degree(self, out, w=None, ):
         if w is None:
             return self.get_out_degrees(out).size
         res = self.get_out_degrees(out, w=w, bsc=1)
